
Accelerator Toolbox (AT) is a collection of tools to model storage rings and beam transport lines.

With AT, it is possible to:

- **create and manipulate accelerator lattice elements**,
- **track particles through the lattice**, selecting the appropriate integrator to represent the physics
- **compute accelerator parameters and beam properties**, generating new scripts or taking advantage of the existing ones

AT is based on a 6-D modular tracking engine written in C/C++ for efficiency.
Lattice manipulation and computation of accelerator physics parameters are provided
by two interfaces:

- a [Matlab interface](https://atcollab.github.io/at/m/index.html), available as a Matlab toolbox,
- a [python interface](https://atcollab.github.io/at/p/index.html#), available as a python package.

## Installation

- For [Matlab](https://atcollab.github.io/at/m/Installation.html)
- For [python](https://atcollab.github.io/at/p/howto/Installation.html)

## Online documentation

- Check the [Web site](https://atcollab.github.io/at/)
- Check the [WIKI](https://github.com/atcollab/at/wiki)
